@@ -189,7 +189,7 @@ class BlockMatrix(MatrixExpr):
             return self._assumptions['shape']
          
         if self.axis:
-            from util.std import argmax
+            from std import argmax
             shapes = [arg.shape for arg in self.args]
             len_shapes = [len(shape) for shape in shapes]
             max_length_index = argmax(len_shapes)
